#!/usr/bin/env python

# Copyright (C) 2009,2010 Junta de Andalucia
# 
# Authors:
#   Roberto Majadas <roberto.majadas at openshine.com>
#   Cesar Garcia Tapia <cesar.garcia.tapia at openshine.com>
#   Luis de Bethencourt <luibg at openshine.com>
#   Pablo Vieytes <pvieytes at openshine.com>
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2, or (at your option)
# any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301
# USA


import os
import gtk

share_files_dir= os.path.join("/usr/local","share/","nanny/client/gnome/admin/")
ui_files_dir= os.path.join(share_files_dir,"ui/")
icons_files_dir= os.path.join(share_files_dir,"icons/")

from AdminConsole import AdminConsole
from ConfigureProxyDialog import ConfigureProxyDialog
from ScheduleCalendar import ScheduleCalendar
from BlacklistManager import BlacklistManager
from DesktopBlocker import DesktopBlocker
